package com.hai.group.impl;

import com.alibaba.fastjson.JSONObject;
import com.hai.common.GenerateCode;
import com.hai.common.QRCodeGenerator;
import com.hai.common.utils.DateUtil;
import com.hai.common.utils.IDGenerator;
import com.hai.config.CommonSysConst;
import com.hai.dao.HighGroupCodeMapper;
import com.hai.dao.HighGroupOrderMapper;
import com.hai.entity.HighGroupCode;
import com.hai.entity.HighGroupCodeExample;
import com.hai.entity.HighGroupOrder;
import com.hai.entity.HighGroupOrderExample;
import com.hai.group.GroupCodeService;
import org.apache.commons.collections4.MapUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Service("groupCodeService")
public class GroupCodeServiceImpl implements GroupCodeService {

    @Resource
    private HighGroupCodeMapper highGroupCodeMapper;

    @Resource
    private HighGroupOrderMapper highGroupOrderMapper;

    @Override
    public void insertGroupCode(HighGroupCode highGroupCode) {
        highGroupCodeMapper.insert(highGroupCode);
    }

    @Override
    public void updateGroupCode(HighGroupCode highGroupCode) {
        highGroupCodeMapper.updateByPrimaryKey(highGroupCode);
    }

    @Override
    public HighGroupCode findGroupCode(Long id) {
        return highGroupCodeMapper.selectByPrimaryKey(id);
    }

    @Override
    public HighGroupCode findGroupCode(Map<String , Object> map) {
        HighGroupCodeExample example = new HighGroupCodeExample();
        HighGroupCodeExample.Criteria criteria = example.createCriteria();


        if (MapUtils.getString(map, "groupCode") != null) {
            criteria.andGroupCodeEqualTo(MapUtils.getString(map, "groupCode"));
        }
        if (MapUtils.getLong(map, "userId") != null) {
            criteria.andUserIdEqualTo(MapUtils.getLong(map, "userId"));
        }
        if (MapUtils.getLong(map, "storeId") != null) {
            criteria.andStoreIdEqualTo(MapUtils.getLong(map, "storeId"));
        }
        if (MapUtils.getLong(map, "orderId") != null) {
            criteria.andOrderIdEqualTo(MapUtils.getLong(map, "orderId"));
        }


        List<HighGroupCode> list = highGroupCodeMapper.selectByExample(example);

        if (list.size() > 0) {
            return list.get(0);
        }

        return null;
    }

    @Override
    public List<HighGroupCode> findGroupCodeList(Map<String, Object> map) {
        HighGroupCodeExample example = new HighGroupCodeExample();
        HighGroupCodeExample.Criteria criteria = example.createCriteria();


        if (MapUtils.getString(map, "groupCode") != null) {
            criteria.andGroupCodeEqualTo(MapUtils.getString(map, "groupCode"));
        }
        if (MapUtils.getLong(map, "userId") != null) {
            criteria.andUserIdEqualTo(MapUtils.getLong(map, "userId"));
        }
        if (MapUtils.getLong(map, "storeId") != null) {
            criteria.andStoreIdEqualTo(MapUtils.getLong(map, "storeId"));
        }

        return highGroupCodeMapper.selectByExample(example);
    }

    @Override
    public HighGroupCode generateCode(Long userId, Long storeId, Long orderId, Long groupId) {

        try {

            HighGroupCode highGroupCode = new HighGroupCode();

            highGroupCode.setGroupId(groupId);
            highGroupCode.setCreateTime(new Date());
            highGroupCode.setOrderId(orderId);
            highGroupCode.setStoreId(storeId);
            highGroupCode.setUpdateTime(new Date());
            highGroupCode.setUserId(userId);
            highGroupCode.setStatus(1);
            insertGroupCode(highGroupCode);
            highGroupCode.setGroupCode(GenerateCode.convertCode(highGroupCode.getId() , 16));

            // 生成二维码
            String qrCodeImg = highGroupCode.getGroupCode() +".png";
            String qrCodeUrl = CommonSysConst.getSysConfig().getFileUrl() + "/groupCode/" + qrCodeImg;
            QRCodeGenerator.generateQRCodeImage(CommonSysConst.getSysConfig().getGroupCode() +  highGroupCode.getGroupCode(), 350, 350, qrCodeUrl);
            highGroupCode.setCodeImgUrl(qrCodeUrl);

            updateGroupCode(highGroupCode);

            return highGroupCode;
        } catch (Exception e) {
            return null;
        }

    }

    @Override
    public void insertGroupOrder(HighGroupOrder highGroupOrder) {
        highGroupOrderMapper.insert(highGroupOrder);
    }

    @Override
    public void updateGroupOrder(HighGroupOrder highGroupOrder) {
        highGroupOrderMapper.updateByPrimaryKey(highGroupOrder);
    }

    @Override
    public HighGroupOrder findGroupOrder(Long groupId) {
        HighGroupOrderExample example = new HighGroupOrderExample();
        HighGroupOrderExample.Criteria criteria = example.createCriteria();

        criteria.andGroupIdEqualTo(groupId);

        List<HighGroupOrder> list = highGroupOrderMapper.selectByExample(example);

        if (!list.isEmpty()) {
            return list.get(0);
        }

        return null;
    }

    @Override
    public HighGroupOrder findGroupOrder(String orderNo) {
        HighGroupOrderExample example = new HighGroupOrderExample();
        HighGroupOrderExample.Criteria criteria = example.createCriteria();

        criteria.andOrderNoEqualTo(orderNo);

        List<HighGroupOrder> list = highGroupOrderMapper.selectByExample(example);

        if (!list.isEmpty()) {
            return list.get(0);
        }

        return null;
    }
}
